import { Elysia } from 'elysia'
import db from '../Database'
import { authenticator } from 'otplib';

const adminController = new Elysia()
.get('/', () => "admin endpoint")
.get('/users', () => {
    const users = db.query(`SELECT id, username, name FROM users;`)
    .all();
    return users
})
.get('/user/groups/:userID', ({params: {userID}}) => {
    const userGroup = db.query(`SELECT groups.GroupId, groups.GroupName FROM groups JOIN userGroups ON groups.GroupID = userGroups.GroupID JOIN users ON userGroups.UserID = users.id WHERE users.id = ?;`)
    .all(userID);
    return userGroup
})
.post('/user/group/:groupId', ({params: {groupId}, body}) => {
    db.query(`INSERT INTO userGroups (UserID, GroupID) VALUES (?, ?);`).run(groupId, body.userId);
    return "Added user to group"
})
.delete('/user/:userId', ({params: {userId}}) => {
    db.query(`DELETE FROM users WHERE id = ?;`).run(userId);

    "deleted user"
})
.post('/register', async({body}) => {
    const password = await Bun.password.hash(body.password);
    const otp = authenticator.generateSecret();
    const res = db.query(`INSERT INTO users(username, password, name, otp) VALUES (?, ?, ?, ?);`).run(body.username, password, body.name, otp);
    return {id: res.lastInsertRowid, username: body.username, name: body.name, otp: otp}
})
.get('/group', () => {
    const groups = db.query(`SELECT GroupID, GroupName FROM groups;`)
    .all();
    return groups
})
.post('/group', ({body}) => {
    const res = db.query(`INSERT INTO groups (GroupName) VALUES (?);`).run(body.name);
    return {GroupID: res.lastInsertRowid, GroupName: body.name}
})
.delete('/group/:groupId', ({ params: { groupId }}) => {
    db.query(`DELETE FROM groups WHERE GroupID = ?;`).run(groupId);

    "deleted group"
})
.delete('/password/:passwordId', ({params: {passwordId}}) => {
    db.query(`DELETE FROM passwords WHERE id = ?;`).run(passwordId);

    "deleted password"
})


export default adminController