// src/components/Header.js
import { useLocation } from 'preact-iso';
import { LogOut } from 'lucide-react';

export function Header() {
    const { url } = useLocation();

    const handleLogout = () => {
        localStorage.removeItem('accessToken');
        localStorage.removeItem('admin'); // Clear admin status
        window.location.href = '/login'; // Redirect to login after logout
    };

    const isAdmin = localStorage.getItem('admin') === "true"

    return (
        <header className="app-header">
            <nav>
                <a href="/" className={url === '/' ? 'active' : ''}>
                    Home
                </a>
                <a href="/profile" className={url === '/profile' ? 'active' : ''}>
                    Profile
                </a>
                {isAdmin && ( // Conditionally render Admin link if user is an admin
                    <a href="/admin" className={url === '/admin' ? 'active' : ''}>
                        Admin
                    </a>
                )}
            </nav>
            {localStorage.getItem('accessToken') && (
                <button onClick={handleLogout} className="logout-button" aria-label="Logout">
                    <LogOut size={24} />
                </button>
            )}
        </header>
    );
}
