import { render } from 'preact';
import { LocationProvider, Router, Route } from 'preact-iso';

import { Header } from './components/Header.js';
import { Home } from './pages/Home/index.js';
import { Login } from './pages/Login/index.js';
import { Profile } from './pages/Profile/index.js';
import { Admin } from './pages/Admin/index.js';
import { NotFound } from './pages/_404.js';
import './style.css';

export function App() {
	const isAuthenticated = !!localStorage.getItem('accessToken');

	const path = window.location.pathname;
	const showHeader = path !== '/login'
	if (!isAuthenticated && path != '/login') {
		window.location.href = "/login"
		return null
	}
	if (isAuthenticated && path == '/login') {
		window.location.href = "/"
		return null
	}


	return (
        <LocationProvider>
            {showHeader && <Header />}
            <main>
                <Router>
                    <Route path="/" component={isAuthenticated ? Home : Login} />
					<Route path="/login" component={isAuthenticated ? Home : Login} />
                    <Route path="/profile" component={isAuthenticated ? Profile : Login} />
                    <Route path="/admin" component={isAuthenticated ? Admin : Login} />
                    <Route default component={NotFound} />
                </Router>
            </main>
        </LocationProvider>
    );
}

render(<App />, document.getElementById('app'));
