import { h } from 'preact';
import { useState } from 'preact/hooks';
import { useLocation } from 'preact-iso';
import API_BASE_URL from '../../config';
import passwordboxLogo from '../../assets/logo.png';
import './style.css';


export function Login() {
    const [username, setUsername] = useState('');
    const [password, setPassword] = useState('');
    const [error, setError] = useState('');
    const location = useLocation();

    const handleLogin = async (event) => {
        event.preventDefault();

        try {
            const response = await fetch(`${API_BASE_URL}/user/login`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ username, password }),
            });

            if (response.status == 401) {
                throw new Error('Login failed');
            }
            if (response.status == 418) {
                localStorage.setItem('admin', "true");
            }
            const data = await response.text();
            // Save the access token in local storage
            localStorage.setItem('accessToken', data);
            // Redirect to the homepage
            window.location.href = '/'; // This will navigate to the homepage
        } catch (err) {
            setError(err.message);
        }
    };

    return (
        <div class="login-container">
			<img src={passwordboxLogo} alt="PasswordBox logo" height="160" width="160" />
            <h2>Login</h2>
            <form onSubmit={handleLogin}>
                <div>
                    <label>Email:</label>
                    <input
                        type="username"
                        value={username}
                        onInput={(e) => setUsername(e.target.value)}
                        required
                    />
                </div>
                <div>
                    <label>Password:</label>
                    <input
                        type="password"
                        value={password}
                        onInput={(e) => setPassword(e.target.value)}
                        required
                    />
                </div>
                {error && <p class="error">{error}</p>}
                <button type="submit">Login</button>
            </form>
        </div>
    );
}
