import { h } from 'preact';
import { useState, useEffect } from 'preact/hooks';
import './style.css';
import API_BASE_URL from '../../config';

export function Profile() {
    const [user, setUser] = useState({ name: '' }); // Initialize with an empty name
    const [isChangingPassword, setIsChangingPassword] = useState(false);
    const [oldPassword, setOldPassword] = useState('');  // For the old password
    const [newPassword, setNewPassword] = useState('');
    const [confirmPassword, setConfirmPassword] = useState('');

    // Fetch user data on component mount
    useEffect(() => {
        const fetchUserData = async () => {
            try {
				const response = await fetch(`${API_BASE_URL}/`, {
                    method: 'GET',
                    headers: {
                        Authorization: `Bearer ${localStorage.getItem('accessToken')}`
                    }
                });
                if (!response.ok) {
                    throw new Error('Failed to fetch user data');
                }
                const data = await response.json();
                setUser({ name: data.name }); // Set user name from response
            } catch (error) {
                alert(error.message);
            }
        };

        fetchUserData();
    }, []); // Empty dependency array means this runs once on mount

    const handleChangePassword = async (e) => {
        e.preventDefault();
        if (newPassword !== confirmPassword) {
            alert("Passwords don't match!");
            return;
        }

        try {
            const response = await fetch(`${API_BASE_URL}/user/password`, {
                method: 'PUT',
                headers: {
					Authorization: `Bearer ${localStorage.getItem('accessToken')}`,
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    oldPassword: oldPassword,
                    newPassword: newPassword,
                }),
            });

            if (!response.ok) {
                throw new Error('Password change failed');
            }

            console.log('Password change requested');
            // Resetting state
            setIsChangingPassword(false);
            setOldPassword('');
            setNewPassword('');
            setConfirmPassword('');
        } catch (error) {
            alert(error.message);
        }
    };

    return (
        <div className="home">
            <section>
                <div className="resource">
                    <h2>Profile Information</h2>
                    <p><strong>Name:</strong> {user.name}</p>
                </div>

                <div className="resource">
                    <h2>Security</h2>
                    {!isChangingPassword ? (
                        <button onClick={() => setIsChangingPassword(true)}>
                            Change Password
                        </button>
                    ) : (
                        <form onSubmit={handleChangePassword}>
                            <input
                                type="password"
                                placeholder="Old Password"
                                value={oldPassword}
                                onChange={(e) => setOldPassword(e.target.value)}
                                required
                            />
                            <input
                                type="password"
                                placeholder="New Password"
                                value={newPassword}
                                onChange={(e) => setNewPassword(e.target.value)}
                                required
                            />
                            <input
                                type="password"
                                placeholder="Confirm New Password"
                                value={confirmPassword}
                                onChange={(e) => setConfirmPassword(e.target.value)}
                                required
                            />
                            <button type="submit">Submit</button>
                            <button type="button" onClick={() => setIsChangingPassword(false)}>
                                Cancel
                            </button>
                        </form>
                    )}
                </div>
            </section>
        </div>
    );
}
